{ config, pkgs, inputs, lib, ... }:
{
  networking.hostName = "foureighty";

  imports = [
    inputs.nixos-hardware.nixosModules.lenovo-thinkpad-t480
    ./custom-kernel.nix
    ./hardware-configuration.nix
    ./tailscale-foureighty.nix
    ../../boot.nix
    ../../common.nix
    ../../tailscale.nix
    ../../distributed-builds.nix
    ../../libvirt.nix
    ../../virtualbox.nix
    ../../backups.nix
    ../../gui
    ../../i3
    ../../git
    ../../mercurial
  ];

  fileSystems."/" = {
    options = [ "compress=zstd" ];
  };

  zramSwap = {
    enable = true;
    algorithm = "zstd";
    memoryPercent = 75;
  };

  time.timeZone = "Europe/London";

  hardware.trackpoint.enable = true;
  services.hardware.bolt.enable = true;
  powerManagement.cpuFreqGovernor = lib.mkDefault "powersave";
  hardware.video.hidpi.enable = lib.mkDefault true;

  services.fprintd = {
    enable = true;
  };

  fonts.fontconfig.enable = true;
  programs.steam.enable = true;

  home-manager.users.cyryl = {...}: {
    imports = [
      ../../home-manager/programs/kitty.nix
    ];
    home.packages = [
      inputs.nixpkgs-nixos-unstable.legacyPackages."x86_64-linux".bisq-desktop
    ];
  };
}
